==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/AverageTrueRangeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageTrueRangeIndicatorStrategy } from "./AverageTrueRangeIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var AverageTrueRangeIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AverageTrueRangeIndicator, _super);
    function AverageTrueRangeIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AverageTrueRangeIndicator.prototype.get_yy = function () {
        return new AverageTrueRangeIndicatorStrategy();
    };
    Object.defineProperty(AverageTrueRangeIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    AverageTrueRangeIndicator.prototype.get_zb = function () {
        return AverageTrueRangeIndicator.$;
    };
    Object.defineProperty(AverageTrueRangeIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AverageTrueRangeIndicator.prototype, "zj", {
        get: function () {
            return typeGetValue(this.c(AverageTrueRangeIndicator.zk));
        },
        set: function (a) {
            this.h(AverageTrueRangeIndicator.zk, a);
        },
        enumerable: false,
        configurable: true
    });
    AverageTrueRangeIndicator.prototype.y4 = function () {
        return this.zj;
    };
    AverageTrueRangeIndicator.prototype.zd = function (a) {
        this.zj = a;
    };
    AverageTrueRangeIndicator.$t = markType(AverageTrueRangeIndicator, 'AverageTrueRangeIndicator', StrategyBasedIndicator.$);
    AverageTrueRangeIndicator.zk = StrategyBasedIndicator.zg(14, AverageTrueRangeIndicator.$);
    return AverageTrueRangeIndicator;
}(StrategyBasedIndicator));
export { AverageTrueRangeIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/AverageTrueRangeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageTrueRangeIndicatorStrategy } from "./AverageTrueRangeIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var AverageTrueRangeIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AverageTrueRangeIndicator, _super);
    function AverageTrueRangeIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AverageTrueRangeIndicator.prototype.bj = function () {
        return new AverageTrueRangeIndicator();
    };
    AverageTrueRangeIndicator.prototype.get_abq = function () {
        return new AverageTrueRangeIndicatorStrategy();
    };
    Object.defineProperty(AverageTrueRangeIndicator.prototype, "abq", {
        get: function () {
            return this.get_abq();
        },
        enumerable: false,
        configurable: true
    });
    AverageTrueRangeIndicator.prototype.get_ab3 = function () {
        return AverageTrueRangeIndicator.$;
    };
    Object.defineProperty(AverageTrueRangeIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AverageTrueRangeIndicator.prototype, "acb", {
        get: function () {
            return typeGetValue(this.c(AverageTrueRangeIndicator.acc));
        },
        set: function (a) {
            this.h(AverageTrueRangeIndicator.acc, a);
        },
        enumerable: false,
        configurable: true
    });
    AverageTrueRangeIndicator.prototype.abw = function () {
        return this.acb;
    };
    AverageTrueRangeIndicator.prototype.ab5 = function (a) {
        this.acb = a;
    };
    AverageTrueRangeIndicator.$t = markType(AverageTrueRangeIndicator, 'AverageTrueRangeIndicator', StrategyBasedIndicator.$);
    AverageTrueRangeIndicator.acc = StrategyBasedIndicator.ab8(14, AverageTrueRangeIndicator.$);
    return AverageTrueRangeIndicator;
}(StrategyBasedIndicator));
export { AverageTrueRangeIndicator };
